paginator

package
v0.0.0-...-50db23e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 27, 2016 License: BSD-3-Clause Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PaginationFunc

type PaginationFunc func(*http.Response) (currentPage []byte, nextPageURL string, dontShadowThis error)

A PaginationFunc processes an http response and returns the current page and a link to the next page if it exists

Directories

Path Synopsis
This file was generated by counterfeiter
This file was generated by counterfeiter

Jump to