comments

package
v0.0.0-...-50db23e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 27, 2016 License: BSD-3-Clause Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Comment

type Comment interface {
	Author() string
	Body() string
}

A Comment represents a comment made on an Issue or Pull Request

func New

func New(rawJSON []byte) ([]Comment, error)

New returns a list of Comment from raw JSON

Directories

Path Synopsis
This file was generated by counterfeiter
This file was generated by counterfeiter

Jump to