commits

package
v0.0.0-...-50db23e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 27, 2016 License: BSD-3-Clause Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Author

type Author interface {
	GitHubID() string
	Email() string
	Name() string
	String() string
}

An Author contains information relating to a commit as seen on GitHub

type Commit

type Commit interface {
	CommitWithoutComments
	Comments() []comments.Comment
}

A Commit represents basic information about a commit including comments

type CommitWithoutComments

type CommitWithoutComments interface {
	Author() Author
	Date() time.Time
	SHA() string
	ParentSHAs() []string
	CommentsURL() string
	String() string
}

A CommitWithoutComments provides basic information relating to a commit

func New

func New(rawJSON []byte) ([]CommitWithoutComments, error)

New returns a list of CommitWithoutComments from raw JSON

Directories

Path Synopsis
This file was generated by counterfeiter This file was generated by counterfeiter This file was generated by counterfeiter
This file was generated by counterfeiter This file was generated by counterfeiter This file was generated by counterfeiter

Jump to