package
Version:
v0.0.0-...-50db23e
Opens a new window with list of versions in this module.
Published: Oct 27, 2016
License: BSD-3-Clause
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Label interface {
Name() string
}
A Label provides basic information about a GitHub label
New returns a slice of Label from raw JSON
Source Files
¶
Directories
¶
This file was generated by counterfeiter
|
This file was generated by counterfeiter |
Click to show internal directories.
Click to hide internal directories.