Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client interface {
FetchCommitsToPathSince(string, time.Time) ([]commits.Commit, error)
FetchCommitsWithCommentsToPathSince(string, time.Time) ([]commits.Commit, error)
FetchIssuesSince(time.Time) ([]issues.Issue, error)
FetchPullRequestsSince(time.Time) ([]prs.PullRequest, error)
FetchPage(string) ([]byte, error)
Done() error
}
A Client handles basic read only operations against the GitHub API
func New ¶
New returns a new github/client.Client that is ready for use callers can control the location of the internal cache file by specifing a non empty cacheFile pointing to the desired cache file which will be
created if it doesn't exist
func NewNonCachingClient ¶
NewNonCachingClient returns a new github/client.Client that is ready for use but does not cache page responses. The client returned is not recommended for use with large repositories due to rate limiting
Directories
¶
| Path | Synopsis |
|---|---|
|
This file was generated by counterfeiter
|
This file was generated by counterfeiter |
|
fetcherfakes
This file was generated by counterfeiter
|
This file was generated by counterfeiter |
|
internal
|
|
|
paginatorfakes
This file was generated by counterfeiter
|
This file was generated by counterfeiter |
Click to show internal directories.
Click to hide internal directories.