Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Commit ¶
type Commit interface {
CommitWithoutComments
Comments() []comments.Comment
}
A Commit represents basic information about a commit including comments
type CommitWithoutComments ¶
type CommitWithoutComments interface {
Author() Author
Date() time.Time
SHA() string
ParentSHAs() []string
CommentsURL() string
String() string
}
A CommitWithoutComments provides basic information relating to a commit
func New ¶
func New(rawJSON []byte) ([]CommitWithoutComments, error)
New returns a list of CommitWithoutComments from raw JSON
Directories
¶
| Path | Synopsis |
|---|---|
|
This file was generated by counterfeiter This file was generated by counterfeiter This file was generated by counterfeiter
|
This file was generated by counterfeiter This file was generated by counterfeiter This file was generated by counterfeiter |
Click to show internal directories.
Click to hide internal directories.