Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Issue ¶
type Issue interface {
IssueWithoutComments
Comments() []comments.Comment
}
An Issue is a composition of a basic issue with comments added
type IssueWithoutComments ¶
type IssueWithoutComments interface {
ID() string
OpenedBy() string
Body() string
CommentsURL() string
Title() string
Open() bool
Labels() []labels.Label
Milestone() milestone.Milestone
Assignees() []string
CreatedAt() time.Time
UpdatedAt() time.Time
}
An IssueWithoutComments represents an issue as returned by the GitHub API
func New ¶
func New(rawJSON []byte) ([]IssueWithoutComments, error)
New returns a slice of issues without comments from raw JSON
Directories
¶
| Path | Synopsis |
|---|---|
|
This file was generated by counterfeiter This file was generated by counterfeiter
|
This file was generated by counterfeiter This file was generated by counterfeiter |
Click to show internal directories.
Click to hide internal directories.